Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(76)

Unified Diff: ash/wm/workspace/workspace_window_resizer.h

Issue 14273008: Add ash-enable-sticky-edges for 'sticky' instead of 'snap' behavior. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Rebase Created 7 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ash/ash_switches.cc ('k') | ash/wm/workspace/workspace_window_resizer.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/wm/workspace/workspace_window_resizer.h
diff --git a/ash/wm/workspace/workspace_window_resizer.h b/ash/wm/workspace/workspace_window_resizer.h
index 4c71285471a31a7e4d7b614bd166d10bb2fbaaf0..424e47d29f4890086fa5d3e49d694360e1a3eb2b 100644
--- a/ash/wm/workspace/workspace_window_resizer.h
+++ b/ash/wm/workspace/workspace_window_resizer.h
@@ -134,16 +134,15 @@ class ASH_EXPORT WorkspaceWindowResizer : public WindowResizer {
// snapping.
void AdjustBoundsForMainWindow(int snap_size, gfx::Rect* bounds);
- // Snaps the window bounds to the work area edges if necessary.
- void SnapToWorkAreaEdges(
- const gfx::Rect& work_area,
- int snap_size,
- gfx::Rect* bounds) const;
-
- // Snaps the window bounds to the work area during a resize.
- void SnapResizeToWorkAreaBounds(const gfx::Rect& work_area,
- int snap_size,
- gfx::Rect* bounds) const;
+ // Stick the window bounds to the work area during a move.
+ void StickToWorkAreaOnMove(const gfx::Rect& work_area,
+ int sticky_size,
+ gfx::Rect* bounds) const;
+
+ // Stick the window bounds to the work area during a resize.
+ void StickToWorkAreaOnResize(const gfx::Rect& work_area,
+ int sticky_size,
+ gfx::Rect* bounds) const;
// Returns a coordinate along the primary axis. Used to share code for
// left/right multi window resize and top/bottom resize.
« no previous file with comments | « ash/ash_switches.cc ('k') | ash/wm/workspace/workspace_window_resizer.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698